# Tutorials

We present here a curated list of notebooks recommended to start with decomon,
available in the `tutorials/` folder of the repository.

```{contents}
---
local: true
---
```

[[notebooks-list]]
